package cn.iocoder.yudao.module.inspection.service;

import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import cn.iocoder.yudao.module.inspection.entity.InspectionCategoryTemplate;

/**
 * 分类模版Service接口
 *
 * @author ruoyi
 * @date 2023-09-07
 */
public interface IInspectionCategoryTemplateService  extends IService<InspectionCategoryTemplate>
{
    /**
     * 查询分类模版
     *
     * @param id 分类模版主键
     * @return 分类模版
     */
    public InspectionCategoryTemplate selectInspectionCategoryTemplateById(Long id);

    /**
     * 查询分类模版列表
     *
     * @param inspectionCategoryTemplate 分类模版
     * @return 分类模版集合
     */
    public IPage<InspectionCategoryTemplate> selectInspectionCategoryTemplateList(Page<InspectionCategoryTemplate> page, InspectionCategoryTemplate inspectionCategoryTemplate);

    /**
     * 新增分类模版
     *
     * @param inspectionCategoryTemplate 分类模版
     * @return 结果
     */
    public int insertInspectionCategoryTemplate(InspectionCategoryTemplate inspectionCategoryTemplate);

    /**
     * 修改分类模版
     *
     * @param inspectionCategoryTemplate 分类模版
     * @return 结果
     */
    public int updateInspectionCategoryTemplate(InspectionCategoryTemplate inspectionCategoryTemplate);

    /**
     * 批量删除分类模版
     *
     * @param ids 需要删除的分类模版主键集合
     * @return 结果
     */
    public int deleteInspectionCategoryTemplateByIds(Long[] ids);

    /**
     * 删除分类模版信息
     *
     * @param id 分类模版主键
     * @return 结果
     */
    public int deleteInspectionCategoryTemplateById(Long id);

    void deleteByCategoryId(Long id);
}
